@@ -5,6 +5,7 @@ import numpy as np
 
 from worker.data.api import API
 from worker.data.enums import EventTypes
+from worker.exceptions import NotFound
 
 
 def gather_data_for_period(asset_id: int, start: int, end: int, limit: int = 1800, collection: str = "wits") -> list:
@@ -67,6 +68,23 @@ def delete_collection_data_of_asset_id(asset_id: int, collections: Union[str, li
         worker.delete(path=path, query=query)
 
 
+def get_drillstring_by_id(drillstring_id: str) -> Union[dict, None]:
+    """
+    Get the drillstring from API by providing mongodb _id
+    :param drillstring_id: mongodb _id of the drillstring
+    :return:
+    """
+    drillstring = None
+    try:
+        drillstring = API().get_by_id(
+            path="/v1/data/corva/", collection='data.drillstring', id=drillstring_id
+        ).data
+    except NotFound:
+        pass
+
+    return drillstring
+
+
 def is_number(data):
     """
     Check and return True if data is a number, else return False
